import { Button, Dropdown, DropdownItem, DropdownMenu, DropdownTrigger, Tooltip } from "@nextui-org/react";
import { MessageSquare, Plus, Users } from "react-feather";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { useTranslation } from "@/hooks/useTranslation";
import usePermissionChat from "@/feature/messenger/hooks/usePermissionChat";

export default function CreateConversationButton() {
    const handleOpenModalNewConversation = useHandleConversationStore(state => state.actions.handleOpenModalNewConversation);
    const handleOpenModalNewContact = useHandleConversationStore(state => state.actions.handleOpenModalNewContact); 
    const { trans } = useTranslation();
    const permisions = usePermissionChat();

    if (!permisions.crear_contacto && !permisions.crea_agenda) {
        return null;
    }

    return (
        <Dropdown placement="top-start">
            <DropdownTrigger>
                <Button 
                    color="primary" 
                    radius="full" 
                    className="min-w-10 min-h-10 size-10 p-0 bg-indigo-500 text-white"
                    aria-label={trans('footer_new_conversation_title')}
                >
                    <Plus size={24} />
                </Button>
            </DropdownTrigger>
            <DropdownMenu 
                aria-label="Nuevas Conversaciones" 
                variant="flat"
                disabledKeys={[]}
            >
                {([
                    permisions.crea_agenda && (
                        <DropdownItem 
                            key="new_contact" 
                            startContent={<Users size={20} />} 
                            description={trans('footer_conversations_dropdown_new_contact_description')} 
                            onPress={handleOpenModalNewContact}
                        >
                            {trans('footer_conversations_dropdown_new_contact_title')}
                        </DropdownItem>
                    ),
                    permisions.crear_contacto && (
                        <DropdownItem 
                            key="new_conversation" 
                            startContent={<MessageSquare size={20} />} 
                            description={trans('footer_conversations_dropdown_start_conversation_drecription')} 
                            onPress={handleOpenModalNewConversation}
                        >
                            {trans('footer_conversations_dropdown_start_conversation_title')}
                        </DropdownItem>
                    )
                ] as const).filter((item): item is JSX.Element => Boolean(item))}
            </DropdownMenu>
        </Dropdown>
    );
}